@@ -63,8 +63,7 @@ func newTreeSimple(cfg *config) tree {
 }
 
 func (t *treeSimple) output(w io.Writer, r io.Reader, cfg *config) error {
-	rg := newRootGeneratorSimple(r, cfg.space)
-	roots, err := rg.generate()
+	roots, err := newRootGeneratorSimple(r).generate()
 	if err != nil {
 		return err
 	}
@@ -83,8 +82,7 @@ func (t *treeSimple) outputProgrammably(w io.Writer, root *Node, cfg *config) er
 }
 
 func (t *treeSimple) mkdir(r io.Reader, cfg *config) error {
-	rg := newRootGeneratorSimple(r, cfg.space)
-	roots, err := rg.generate()
+	roots, err := newRootGeneratorSimple(r).generate()
 	if err != nil {
 		return err
 	}
@@ -110,8 +108,7 @@ func (t *treeSimple) mkdirProgrammably(root *Node, cfg *config) error {
 }
 
 func (t *treeSimple) verify(r io.Reader, cfg *config) error {
-	rg := newRootGeneratorSimple(r, cfg.space)
-	roots, err := rg.generate()
+	roots, err := newRootGeneratorSimple(r).generate()
 	if err != nil {
 		return err
 	}
